@@ -378,6 +378,18 @@ class ExplainerDashboard:
 
         self.app = self._get_dash_app()
         if logins is not None:
+            if len(logins)==2 and isinstance(logins[0], str) and isinstance(logins[1], str):
+                logins = [logins]
+            assert isinstance(logins, list), \
+                ("Parameter logins should be a list of lists of str pairs, e.g."
+                 " logins=[['user1', 'password1'], ['user2', 'password2']]!")
+            for login in logins:
+                assert isinstance(login, list), \
+                    ("Parameter logins should be a list of lists of str pairs, "
+                     "e.g. logins=[['user1', 'password1'], ['user2', 'password2']]!")
+                assert isinstance(login[0], str) and isinstance(login[1], str), \
+                    ("For logins such as [['user1', 'password1']] user1 and "
+                     "password1 should be type(str)!")
             self.auth = dash_auth.BasicAuth(self.app, logins)
         self.app.title = title
 
@@ -665,38 +677,36 @@ class ExplainerDashboard:
 
     def _get_dash_app(self):
         if self.responsive:
-            meta_tags = [{'name': 'viewport', 'content': 'width=device-width, initial-scale=1.0, maximum-scale=1.2, minimum-scale=0.5,'}]
+            meta_tags = [
+                {'name': 'viewport', 
+                'content': 'width=device-width, initial-scale=1.0, maximum-scale=1.2, minimum-scale=0.5,'}
+                ]
         else:
             meta_tags = None
+        
+        if self.bootstrap is not None:
+            assets_ignore = '^bootstrap.min.css$' 
+        else:
+            assets_ignore = ""
         if self.mode=="dash":
-            if self.external_stylesheets is not None:
-                app = dash.Dash(server=self.server, 
-                                external_stylesheets=self.external_stylesheets, 
-                                assets_url_path="", 
-                                url_base_pathname=self.url_base_pathname,
-                                meta_tags=meta_tags)
-                app.config['suppress_callback_exceptions'] = True
-            else:
-                app = dash.Dash(__name__, 
-                                server=self.server, 
-                                url_base_pathname=self.url_base_pathname,
-                                meta_tags=meta_tags)
-                app.config['suppress_callback_exceptions'] = True
-                app.css.config.serve_locally = True
-                app.scripts.config.serve_locally = True
-            return app
-        elif self.mode in ['inline', 'jupyterlab', 'external']:
-            if self.external_stylesheets is not None:
-                app = JupyterDash(
+            app = dash.Dash(__name__,
+                            server=self.server, 
                             external_stylesheets=self.external_stylesheets, 
-                            assets_url_path="",
+                            assets_ignore=assets_ignore,
+                            url_base_pathname=self.url_base_pathname,
+                            meta_tags=meta_tags)
+        elif self.mode in ['inline', 'jupyterlab', 'external']:
+            app = JupyterDash(__name__,
+                            external_stylesheets=self.external_stylesheets, 
+                            assets_ignore=assets_ignore,
                             meta_tags=meta_tags)
-            else:
-                app = JupyterDash(__name__)
-            return app
         else:
             raise ValueError(f"mode=={self.mode} but should be in "
-                 "['dash', 'inline', 'juypyterlab', 'external']")
+                 "{'dash', 'inline', 'juypyterlab', 'external'}")
+        app.config['suppress_callback_exceptions'] = True
+        app.scripts.config.serve_locally = True
+        app.css.config.serve_locally = True
+        return app
 
     def flask_server(self):
         """returns self.app.server so that it can be exposed to e.g. gunicorn"""
